@@ -1,16 +1,24 @@
 from collections import defaultdict
-from typing import List
+from typing import Any, Dict, List, Union
 
 from petisco.base.application.dependency_injection.dependency import Dependency
 from petisco.base.misc.singleton import Singleton
 
 
 class Container(metaclass=Singleton):
-    def __init__(self):
-        self.dependencies = defaultdict()
+    """
+    Singleton which contains set dependencies (List[Dependency)) prepared to be instantiated in order to be injected
+     in the UseCases of our application
+    """
+
+    def __init__(self) -> None:
+        self.dependencies: Dict[str, Dependency] = defaultdict()
 
     @staticmethod
-    def get(name: str):
+    def get(name: str) -> Any:
+        """
+        Returns an instance of set Dependency.
+        """
         container = Container()
         dependency = container.dependencies.get(name)
         if dependency is None:
@@ -21,16 +29,22 @@ class Container(metaclass=Singleton):
         return instance
 
     @staticmethod
-    def set_dependencies(dependencies: List[Dependency] = None):
+    def set_dependencies(dependencies: Union[List[Dependency], None] = None) -> None:
+        """
+        Set dependencies from a list of them.
+        """
         if dependencies is None:
             dependencies = []
         Container()._set_dependencies(dependencies)
 
     @staticmethod
     def get_available_dependencies() -> List[str]:
+        """
+        Returns the names (keys) of set dependencies.
+        """
         return list(Container().dependencies.keys())
 
-    def _set_dependencies(self, input_dependencies: List[Dependency]):
+    def _set_dependencies(self, input_dependencies: List[Dependency]) -> None:
         for dependency in input_dependencies:
             if dependency.name not in self.dependencies:
                 self.dependencies[dependency.name] = dependency
