@@ -1,10 +1,10 @@
 from abc import ABC, abstractmethod
 from functools import wraps
 from types import FunctionType
-from typing import Any
+from typing import Any, Callable, Dict, Tuple
 
 import elasticapm
-from meiga import Error, Failure, NotImplementedMethodError, Result
+from meiga import AnyResult, Error, Failure, NotImplementedMethodError
 from meiga.on_failure_exception import OnFailureException
 
 from petisco.base.application.use_case.use_case_uncontrolled_error import (
@@ -12,13 +12,16 @@ from petisco.base.application.use_case.use_case_uncontrolled_error import (
 )
 
 
-def wrapper(method, wrapped_class_name):
+def wrapper(
+    method: Callable[..., AnyResult], wrapped_class_name: str
+) -> Callable[..., AnyResult]:
     @wraps(method)
-    def wrapped(*args, **kwargs):
+    def wrapped(*args: Any, **kwargs: Any) -> AnyResult:
         try:
             return method(*args, **kwargs)
         except OnFailureException as exception:
-            return exception.result
+            # TODO create issue to add typing on OnFailureException meiga class
+            return exception.result  # type: ignore
         except Error as error:
             return Failure(error)
         except Exception as exception:
@@ -35,7 +38,9 @@ def wrapper(method, wrapped_class_name):
 
 
 class MetaUseCase(type, ABC):
-    def __new__(mcs, name, bases, namespace):
+    def __new__(
+        mcs, name: str, bases: Tuple[Any], namespace: Dict[str, Any]
+    ) -> "MetaUseCase":
         new_class_dict = {}
         if "execute" not in namespace:
             raise NotImplementedError(
@@ -49,11 +54,11 @@ class MetaUseCase(type, ABC):
         return type.__new__(mcs, name, bases, new_class_dict)
 
     @abstractmethod
-    def execute(self, *args, **kwargs) -> Result[Any, Error]:
+    def execute(self, *args: Any, **kwargs: Any) -> AnyResult:
         return NotImplementedMethodError
 
 
 class UseCase(metaclass=MetaUseCase):
     @abstractmethod
-    def execute(self, *args, **kwargs) -> Result[Any, Error]:
+    def execute(self, *args: Any, **kwargs: Any) -> AnyResult:
         return NotImplementedMethodError
