@@ -12,9 +12,9 @@ class MessageConfigurer(Interface):
         subscribers: List[MessageSubscriber],
         clear_subscriber_before: bool = False,
         clear_store_before: bool = False,
-    ):
+    ) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    def clear(self):
+    def clear(self) -> None:
         raise NotImplementedError
