@@ -1,16 +1,21 @@
 import re
 from abc import abstractmethod
 from types import FunctionType
-from typing import List, Type
+from typing import Any, Dict, List, Tuple, Type
 
 from meiga import BoolResult
 
+from petisco.base.application.middleware.middleware import Middleware
 from petisco.base.domain.message.command_bus import CommandBus
 from petisco.base.domain.message.domain_event_bus import DomainEventBus
 from petisco.base.domain.message.message import Message
+from petisco.base.domain.message.message_bus import TypeMessage
 from petisco.base.domain.message.message_subscriber_info import MessageSubscriberInfo
-from petisco.base.domain.message.not_implemented_message_bus import (
-    NotImplementedMessageBus,
+from petisco.base.domain.message.not_implemented_command_bus import (
+    NotImplementedCommandBus,
+)
+from petisco.base.domain.message.not_implemented_domain_event_bus import (
+    NotImplementedDomainEventBus,
 )
 from petisco.base.misc.interface import Interface
 from petisco.base.misc.result_mapper import ResultMapper
@@ -18,11 +23,13 @@ from petisco.base.misc.wrapper import wrapper
 
 
 class MetaMessageSubscriber(type, Interface):
-    domain_event_bus: DomainEventBus = NotImplementedMessageBus()
-    command_bus: CommandBus = NotImplementedMessageBus()
-    middlewares: List = {}
+    domain_event_bus: DomainEventBus = NotImplementedDomainEventBus()
+    command_bus: CommandBus = NotImplementedCommandBus()
+    middlewares: List[Middleware] = []
 
-    def __new__(mcs, name, bases, namespace):
+    def __new__(
+        mcs, name: str, bases: Tuple[Any, ...], namespace: Dict[str, Any]
+    ) -> "MetaMessageSubscriber":
         config = namespace.get("Config")
 
         if "handle" not in namespace:
@@ -51,24 +58,24 @@ class MetaMessageSubscriber(type, Interface):
 
 class MessageSubscriber(metaclass=MetaMessageSubscriber):
     @abstractmethod
-    def subscribed_to(self) -> List[Type[Message]]:
+    def subscribed_to(self) -> Any:
         raise NotImplementedError()
 
     @abstractmethod
-    def handle(self, message: Message) -> BoolResult:
+    def handle(self, message: TypeMessage) -> BoolResult:
         raise NotImplementedError()
 
     @classmethod
-    def __repr__(cls):
-        subscriptions = cls.subscribed_to(cls)
+    def __repr__(cls) -> str:
+        subscriptions = cls.subscribed_to(cls)  # type: ignore
         if not isinstance(subscriptions, list):
             subscriptions = [subscriptions]
         return f"{cls.__name__}: subscribed_to {[class_type.__name__ for class_type in subscriptions]}"
 
-    def set_domain_event_bus(self, domain_event_bus: DomainEventBus):
+    def set_domain_event_bus(self, domain_event_bus: DomainEventBus) -> None:
         self.domain_event_bus = domain_event_bus
 
-    def set_command_bus(self, command_bus: CommandBus):
+    def set_command_bus(self, command_bus: CommandBus) -> None:
         self.command_bus = command_bus
 
     def get_subscriber_name(self) -> str:
