@@ -3,10 +3,10 @@ from petisco.base.domain.message.command_bus import CommandBus
 
 
 class NotImplementedCommandBus(CommandBus):
-    def dispatch(self, command: Command):
+    def dispatch(self, command: Command) -> None:
         self._check_is_command(command)
         meta = self.get_configured_meta()
         _ = command.update_meta(meta)
 
-    def close(self):
+    def close(self) -> None:
         pass
