@@ -8,12 +8,20 @@ from petisco.base.domain.model.value_object import ValueObject
 
 
 class Uuid(ValueObject):
+    """
+    A base class to define Uuid
+
+    Use it to identify domain entities
+    """
+
+    value: str
+
     @validator("value")
-    def validate_value(cls, value):
+    def validate_value(cls, value: str) -> str:
         if value is None or not validators.uuid(value):
             raise InvalidUuid(uuid_value=value)
         return value
 
-    @staticmethod
-    def v4():
-        return Uuid(value=str(uuid4()))
+    @classmethod
+    def v4(cls) -> "Uuid":
+        return cls(value=str(uuid4()))
