@@ -1,4 +1,4 @@
-from typing import List
+from typing import Any, List
 
 from petisco.base.domain.persistence.interface_database import Database
 from petisco.base.domain.persistence.persistence_models import PersistenceModels
@@ -9,16 +9,16 @@ class FakeDatabase(Database):
         models = PersistenceModels.from_filename(model_filename).get_models_names()
         super().__init__(name, models=models)
 
-    def create(self):
+    def create(self) -> None:
         pass
 
-    def delete(self):
+    def delete(self) -> None:
         pass
 
-    def clear_data(self):
+    def clear_data(self) -> None:
         pass
 
-    def get_model(self, model_name: str):
+    def get_model(self, model_name: str) -> Any:
         model = self.models.get(model_name)
         if not model:
             raise IndexError(
