@@ -1,32 +1,32 @@
 from abc import ABC, abstractmethod
-from typing import Dict, List
+from typing import Any, Dict, List, Union
 
 
 class Database(ABC):
-    def __init__(self, name: str, models: Dict = None):
+    def __init__(self, name: str, models: Union[Dict[str, Any], None] = None):
         self.name = name
         self.models = models if models else {}
 
-    def info(self) -> Dict:
-        _info = {"name": self.name}
+    def info(self) -> Dict[str, Any]:
+        _info: Dict[str, Any] = {"name": self.name}
         if self.models:
             _info["models"] = self.models
         return _info
 
     @abstractmethod
-    def create(self):
+    def create(self) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    def delete(self):
+    def delete(self) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    def clear_data(self):
+    def clear_data(self) -> None:
         raise NotImplementedError
 
     @abstractmethod
-    def get_model(self, model_name: str):
+    def get_model(self, model_name: str) -> Any:
         raise NotImplementedError
 
     @abstractmethod
