@@ -1,11 +1,12 @@
 import os
+from typing import Dict, List, Optional, Tuple, Union
 
 
 class ElasticConnection:
     def __init__(
         self,
-        username: str = None,
-        password: str = None,
+        username: Optional[str] = None,
+        password: Optional[str] = None,
         host: str = "http://localhost",
         port: str = "9200",
     ):
@@ -15,22 +16,24 @@ class ElasticConnection:
         self.port = port
 
     @property
-    def http_auth(self):
+    def http_auth(self) -> Union[Tuple[str, str], None]:
         http_auth = None
         if self.username and self.password:
             http_auth = (self.username, self.password)
         return http_auth
 
     @staticmethod
-    def create(username: str, password: str, host: str, port: str):
+    def create(
+        username: str, password: str, host: str, port: str
+    ) -> "ElasticConnection":
         return ElasticConnection(username, password, host, port)
 
     @staticmethod
-    def create_local():
+    def create_local() -> "ElasticConnection":
         return ElasticConnection(host="http://localhost")
 
     @staticmethod
-    def from_environ():
+    def from_environ() -> "ElasticConnection":
         return ElasticConnection.create(
             os.getenv("ELASTIC_USERNAME", ""),
             os.getenv("ELASTIC_PASSWORD", ""),
@@ -38,7 +41,7 @@ class ElasticConnection:
             os.getenv("ELASTIC_PORT", "9200"),
         )
 
-    def to_elastic_format(self):
+    def to_elastic_format(self) -> Union[List[str], List[Dict[str, str]]]:
         if self.host.startswith("http"):
             return [f"{self.host}:{self.port}"]
         else:
