@@ -1,12 +1,15 @@
+import os
 import threading
 import traceback
 from dataclasses import dataclass
 from time import sleep
-from typing import Callable, List, Optional, Type
+from typing import Any, Callable, Dict, List, NoReturn, Optional, Type, Union
 
+from loguru import logger
 from meiga import Failure
 from pika import BasicProperties
 from pika.adapters.blocking_connection import BlockingChannel
+from pika.exceptions import ConnectionClosedByBroker
 from pika.spec import Basic
 
 from petisco.base.domain.message.chaos.message_chaos import MessageChaos
@@ -48,6 +51,13 @@ from petisco.extra.rabbitmq.shared.rabbitmq_exchange_name_formatter import (
 from petisco.legacy.logger.interface_logger import ILogger
 from petisco.legacy.logger.not_implemented_logger import NotImplementedLogger
 
+MAX_ATTEMPTS_TO_RECONNECT = int(
+    os.getenv("PETISCO_RABBITMQ_MAX_ATTEMPTS_TO_RECONNECT_CONSUMER", "20")
+)
+WAIT_SECONDS_TO_RECONNECT = int(
+    os.getenv("PETISCO_RABBITMQ_WAIT_SECONDS_TO_RECONNECT_CONSUMER", "5")
+)
+
 
 @dataclass
 class SubscriberItem:
@@ -58,6 +68,10 @@ class SubscriberItem:
 
 
 class RabbitMqMessageConsumer(MessageConsumer):
+    """
+    A RabbitMQ consumer to link received messages from rabbitmq with defined subscribers.
+    """
+
     def __init__(
         self,
         organization: str,
@@ -67,7 +81,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
         verbose: bool = False,
         chaos: MessageChaos = NotImplementedMessageChaos(),
         logger: Optional[ILogger] = NotImplementedLogger(),
-    ):
+    ) -> None:
         self.connector = connector
         self.organization = organization
         self.service = service
@@ -79,9 +93,13 @@ class RabbitMqMessageConsumer(MessageConsumer):
         self.printer = RabbitMqEventConsumerPrinter(verbose)
         self.consumer_logger = RabbitMqMessageConsumerLogger(logger)
         self.chaos = chaos
-        self.subscribers = {}
+        self.subscribers: Dict[str, SubscriberItem] = {}
+        self._thread: Union[threading.Thread, None] = None
 
-    def start(self):
+    def start(self) -> NoReturn:
+        """
+        Start the process of consuming messages from RabbitMQ and pass to subscriber.
+        """
         if not self._channel:
             raise RuntimeError(
                 "RabbitMqMessageConsumer: cannot start consuming event without any subscriber defined."
@@ -89,10 +107,43 @@ class RabbitMqMessageConsumer(MessageConsumer):
         self._thread = threading.Thread(target=self._start)
         self._thread.start()
 
-    def _start(self):
-        self._channel.start_consuming()
+    def _start(self) -> None:
+        try:
+            self._channel.start_consuming()
+        except ConnectionClosedByBroker:
+            self._re_connect(attempt=1)
+
+    def _re_connect(self, attempt: int):
+        if attempt >= MAX_ATTEMPTS_TO_RECONNECT:
+            raise ConnectionError(
+                f"Impossible to reconnect consumer '{self.rabbitmq_key}' after {attempt} attempts"
+            )
+
+        logger.info(
+            f"Trying to reconnect consumer '{self.rabbitmq_key}' (attempt {attempt})"
+        )
+
+        try:
+            self._channel = self.connector.get_channel(self.rabbitmq_key)
+        except ConnectionError:
+            sleep(WAIT_SECONDS_TO_RECONNECT)
+            attempt += 1
+            self._re_connect(attempt=attempt)
+        else:
+            subscribers = [
+                item.subscriber.__class__ for item in self.subscribers.values()
+            ]
+            self.add_subscribers(subscribers)
+            self.start()
+            logger.info(
+                f"Consumer '{self.rabbitmq_key}' reconnected after {attempt} attempts"
+            )
+
+    def add_subscribers(self, subscribers: List[Type[MessageSubscriber]]) -> None:
+        """
+        Add defined subscribers to be connected with main queues.
+        """
 
-    def add_subscribers(self, subscribers: List[Type[MessageSubscriber]]):
         for SubscriberClass in subscribers:
 
             subscriber: MessageSubscriber = SubscriberClass()
@@ -113,7 +164,12 @@ class RabbitMqMessageConsumer(MessageConsumer):
                         message_type_expected=subscriber_info.message_type,
                     )
 
-    def add_subscriber_on_dead_letter(self, subscriber: Type[MessageSubscriber]):
+    def add_subscriber_on_dead_letter(
+        self, subscriber: Type[MessageSubscriber]
+    ) -> None:
+        """
+        Add defined subscribers to be connected with the correspondent dead letter.
+        """
         instance_subscriber: MessageSubscriber = subscriber()
         for subscriber_info in instance_subscriber.get_message_subscribers_info():
 
@@ -126,16 +182,13 @@ class RabbitMqMessageConsumer(MessageConsumer):
                 message_type_expected=subscriber_info.message_type,
             )
 
-    # def add_handler_on_store(self, handler: Callable):
-    #     self.add_handler_on_queue("store", handler, is_store=True)
-
     def _add_subscriber_instance_on_queue(
         self,
         queue_name: str,
         subscriber: MessageSubscriber,
         is_store: bool = False,
         message_type_expected: str = "message",
-    ):
+    ) -> None:
         consumer_tag = self._channel.basic_consume(
             queue=queue_name,
             on_message_callback=self.consumer(
@@ -152,11 +205,14 @@ class RabbitMqMessageConsumer(MessageConsumer):
         subscriber: Type[MessageSubscriber],
         is_store: bool = False,
         message_type_expected: str = "message",
-    ):
-        subscriber: MessageSubscriber = subscriber()
-        return self._add_subscriber_instance_on_queue(
+    ) -> None:
+        """
+        Add defined subscribers to be connected with a specific queue name.
+        """
+        subscriber_instance: MessageSubscriber = subscriber()
+        self._add_subscriber_instance_on_queue(
             queue_name=queue_name,
-            subscriber=subscriber,
+            subscriber=subscriber_instance,
             is_store=is_store,
             message_type_expected=message_type_expected,
         )
@@ -166,13 +222,13 @@ class RabbitMqMessageConsumer(MessageConsumer):
         subscriber: MessageSubscriber,
         is_store: bool = False,
         message_type_expected: str = "message",
-    ) -> Callable:
+    ) -> Callable[..., None]:
         def rabbitmq_consumer(
             ch: BlockingChannel,
             method: Basic.Deliver,
             properties: BasicProperties,
             body: bytes,
-        ):
+        ) -> None:
             self.printer.print_received_message(method, properties, body)
 
             if self.chaos.nack_simulation(ch, method):
@@ -188,7 +244,6 @@ class RabbitMqMessageConsumer(MessageConsumer):
                     subscriber.handle,
                     log_activity="received_message",
                 )
-
             try:
                 if message_type_expected == "domain_event":
                     message = DomainEvent.from_json(body)
@@ -220,7 +275,6 @@ class RabbitMqMessageConsumer(MessageConsumer):
                 )
                 subscriber.set_domain_event_bus(domain_event_bus)
                 subscriber.set_command_bus(command_bus)
-
                 result = subscriber.handle(message)
 
             self.printer.print_context(subscriber.handle, result)
@@ -229,6 +283,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
                 raise MessageHandlerReturnsNoneError(subscriber.handle)
 
             derived_action = ConsumerDerivedAction()
+
             if result.is_failure:
                 if not properties.headers:
                     properties.headers = {
@@ -260,7 +315,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
         properties: BasicProperties,
         body: bytes,
         is_store: bool,
-    ):
+    ) -> ConsumerDerivedAction:
 
         if self.has_been_redelivered_too_much(properties):
             derived_action = self.send_to_dead_letter(ch, method, properties, body)
@@ -271,15 +326,16 @@ class RabbitMqMessageConsumer(MessageConsumer):
 
         return derived_action
 
-    def has_been_redelivered_too_much(self, properties: BasicProperties):
+    def has_been_redelivered_too_much(self, properties: BasicProperties) -> bool:
         if not properties.headers or "redelivery_count" not in properties.headers:
             if self.max_retries < 1:
                 return True
             return False
         else:
-            return properties.headers.get("redelivery_count") >= self.max_retries
+            redelivery_count: int = properties.headers.get("redelivery_count")
+            return bool(redelivery_count >= self.max_retries)
 
-    def _get_routing_key(self, routing_key: str, prefix: str):
+    def _get_routing_key(self, routing_key: str, prefix: str) -> str:
         if routing_key.startswith("retry."):
             routing_key = routing_key.replace("retry.", prefix, 1)
         elif routing_key.startswith("dead_letter."):
@@ -295,7 +351,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
         properties: BasicProperties,
         body: bytes,
         is_store: bool = False,
-    ):
+    ) -> ConsumerDerivedAction:
         self.printer.print_action("send_to_retry")
         exchange_name = RabbitMqExchangeNameFormatter.retry(self.exchange_name)
 
@@ -307,6 +363,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
             routing_key = "store"
             exchange_name = self._fallback_store_exchange_name
 
+        assert isinstance(routing_key, str)
         routing_key = self._get_routing_key(routing_key, "retry.")
 
         updated_headers = self.send_message_to(
@@ -325,9 +382,10 @@ class RabbitMqMessageConsumer(MessageConsumer):
         method: Basic.Deliver,
         properties: BasicProperties,
         body: bytes,
-    ):
+    ) -> ConsumerDerivedAction:
         self.printer.print_action("send_to_dead_letter")
         exchange_name = RabbitMqExchangeNameFormatter.dead_letter(self.exchange_name)
+        assert isinstance(method.routing_key, str)
         routing_key = self._get_routing_key(method.routing_key, "dead_letter.")
         updated_headers = self.send_message_to(
             exchange_name, ch, routing_key, properties, body
@@ -346,7 +404,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
         routing_key: str,
         properties: BasicProperties,
         body: bytes,
-    ):
+    ) -> Dict[str, Any]:
         if properties.headers:
             redelivery_count = properties.headers.get("redelivery_count", 0)
             properties.headers["redelivery_count"] = redelivery_count + 1
@@ -354,7 +412,7 @@ class RabbitMqMessageConsumer(MessageConsumer):
             properties.headers = {"redelivery_count": 1}
 
         self.printer.print_send_message_to(
-            exchange_name, routing_key, properties.headers
+            exchange_name, routing_key, dict(properties.headers)
         )
 
         ch.basic_publish(
@@ -364,18 +422,16 @@ class RabbitMqMessageConsumer(MessageConsumer):
             properties=properties,
         )
 
-        return properties.headers
+        return dict(properties.headers)
 
-    def stop(self):
-        def _log_stop_exception(e: Exception):
-            from petisco.legacy import ERROR, LogMessage, Petisco
+    def stop(self) -> None:
+        """
+        Stop the process of consuming messages from RabbitMQ.
+        """
 
-            logger = Petisco.get_logger()
-            log_message = LogMessage(
-                layer="petisco", operation="RabbitMQEventSubscriber"
-            )
-            message = f"Error stopping RabbitMQEventSubscriber: {repr(e.__class__)} {e} | {traceback.format_exc()}"
-            logger.log(ERROR, log_message.set_message(message))
+        def _log_stop_exception(e: Exception) -> None:
+            message = f"Error stopping RabbitMQMessageConsumer: {repr(e.__class__)} {e} | {traceback.format_exc()}"
+            logger.error(message)
 
         if self._thread and self._thread.is_alive():
             self._unsubscribe_all()
@@ -385,15 +441,15 @@ class RabbitMqMessageConsumer(MessageConsumer):
             except Exception as e:
                 _log_stop_exception(e)
 
-    def _unsubscribe_all(self):
-        def _stop_consuming_consumer_channel():
+    def _unsubscribe_all(self) -> None:
+        def _stop_consuming_consumer_channel() -> None:
             try:
                 self._channel.stop_consuming()
                 self._channel.cancel()
             except ValueError:
                 pass
 
-        def _await_for_stop_consuming_consumer_channel():
+        def _await_for_stop_consuming_consumer_channel() -> None:
             sleep(2.0)
 
         self.connector.get_connection(self.rabbitmq_key).call_later(
@@ -402,26 +458,28 @@ class RabbitMqMessageConsumer(MessageConsumer):
 
         _await_for_stop_consuming_consumer_channel()
 
-    def unsubscribe_subscriber_on_queue(self, queue_name: str):
-        subscriber_item: SubscriberItem = self.subscribers.get(queue_name)
+    def unsubscribe_subscriber_on_queue(self, queue_name: str) -> None:
+        subscriber_item = self.subscribers.get(queue_name)
         if subscriber_item is None:
             raise IndexError(
                 f"Cannot unsubscribe an nonexistent queue ({queue_name}). Please, check configured consumers ({list(self.subscribers.keys())})"
             )
 
-        def _unsubscribe_handler_on_queue():
+        def _unsubscribe_handler_on_queue() -> None:
+            assert isinstance(subscriber_item, SubscriberItem)
             self._channel.basic_cancel(consumer_tag=subscriber_item.consumer_tag)
 
         self._do_it_in_consumer_thread(_unsubscribe_handler_on_queue)
 
-    def resume_subscriber_on_queue(self, queue_name: str):
-        subscriber_item: SubscriberItem = self.subscribers.get(queue_name)
+    def resume_subscriber_on_queue(self, queue_name: str) -> None:
+        subscriber_item = self.subscribers.get(queue_name)
         if subscriber_item is None:
             raise IndexError(
                 f"Cannot resume an nonexistent queue ({queue_name}). Please, check configured consumers ({list(self.subscribers.keys())})"
             )
 
-        def _resume_handler_on_queue():
+        def _resume_handler_on_queue() -> None:
+            assert isinstance(subscriber_item, SubscriberItem)
             subscriber_item.consumer_tag = self._channel.basic_consume(
                 queue=subscriber_item.queue_name,
                 on_message_callback=self.consumer(
@@ -431,14 +489,14 @@ class RabbitMqMessageConsumer(MessageConsumer):
 
         self._do_it_in_consumer_thread(_resume_handler_on_queue)
 
-    def _do_it_in_consumer_thread(self, action: Callable):
-        def _execute_action():
+    def _do_it_in_consumer_thread(self, action: Callable[..., None]) -> None:
+        def _execute_action() -> None:
             try:
                 action()
             except ValueError:
                 pass
 
-        def _await_for_thread():
+        def _await_for_thread() -> None:
             sleep(2.0)
 
         self.connector.get_connection(self.rabbitmq_key).call_later(0, _execute_action)
