@@ -1,9 +1,4 @@
-# coding=utf-8
-# Copyright (C) 2021+ Alice, Vigo, Spain
-
 """Public API of Alice Petisco Framework"""
-from typing import List, Type
-
 from petisco.base.application.application import Application
 from petisco.base.application.application_configurer import ApplicationConfigurer
 from petisco.base.application.controller.controller import Controller
@@ -89,9 +84,11 @@ from petisco.base.domain.persistence.persistence_models import PersistenceModels
 from petisco.base.misc.builder import Builder
 from petisco.base.misc.interface import Interface
 from petisco.base.misc.result_mapper import ResultMapper
+from petisco.base.misc.singleton import Singleton
 from petisco.base.testing.assert_http import assert_http
 
-base = [
+__all__ = [
+    # base
     "Controller",
     "ResultMapper",
     "Middleware",
@@ -135,9 +132,8 @@ base = [
     "Application",
     "ApplicationConfigurer",
     "Builder",
-]
-
-errors = [
+    "Singleton",
+    # error
     "DEFAULT_HTTP_ERROR_MAP",
     "DomainError",
     "CriticalError",
@@ -156,10 +152,6 @@ errors = [
     "InvalidValueObject",
     "HttpError",
     "ErrorMap",
+    # deprecated
+    "Injector",
 ]
-
-
-deprecated = ["Injector"]
-modules: List[str] = []
-
-__all__ = base + errors + deprecated + modules
